@@ -4,7 +4,7 @@ from os import path, makedirs
 from .getEnv import getEnv
 from dotenv import load_dotenv
 
-__all__ = ['rootCwd', 'binCwd', 'envCwd', 'sundayLoginCwd', 'sundayToolsCwd']
+__all__ = ['rootCwd', 'logCwd', 'binCwd', 'envCwd', 'sundayLoginCwd', 'sundayToolsCwd']
 
 # sunday家目录
 userHomeCwd = path.expanduser('~')
@@ -12,9 +12,10 @@ rootCwd = getEnv('SUNDAY_ROOT') or path.join(userHomeCwd, '.sunday')
 homePluginsCwd = path.join(rootCwd, 'plugins')
 binCwd = path.join(rootCwd, 'bin')
 envCwd = path.join(rootCwd, '.env')
+logCwd = path.join(rootCwd, 'log')
 path.exists(envCwd) and load_dotenv(envCwd)
 
-for p in [binCwd, homePluginsCwd]:
+for p in [binCwd, logCwd, homePluginsCwd]:
     if not path.exists(p): makedirs(p)
 
 # sunday模块目录
